@@ -31,7 +31,7 @@ def part_to_child(stu_part, sol_part, append_message, state, node_name=None):
     # otherwise, assume they are just nodes
     return state.to_child_state(student_subtree=stu_part,
                                 solution_subtree=sol_part,
-                                append_message = append_message)
+                                append_message=append_message)
 
 
 DEFAULT_PART_MISSING_MSG="__JINJA__:Are you sure you defined the {{part}}? "
@@ -80,8 +80,10 @@ def check_part_index(name, index, part_msg,
     fmt_kwargs = {'index': index, 'ordinal': ordinal}
     fmt_kwargs['part'] = part_msg.format(**fmt_kwargs)
 
-    append_message = {'msg': expand_msg,
-                      'kwargs': fmt_kwargs}
+    append_message = {
+        'msg': expand_msg,
+        'kwargs': fmt_kwargs
+    }
 
     # check there are enough parts for index
     has_part(name, missing_msg, state, append_message['kwargs'], index)
@@ -133,9 +135,10 @@ def check_node(name, index=0, typestr='{ordinal} node',
     stu_part = stu_out[index]
     sol_part = sol_out[index]
 
-    append_message = {'msg': expand_msg,
-                      'kwargs': fmt_kwargs
-                      }
+    append_message = {
+        'msg': expand_msg,
+        'kwargs': fmt_kwargs
+    }
 
     return part_to_child(stu_part, sol_part, append_message, state, node_name=name)
 
@@ -341,7 +344,7 @@ def set_context(*args, state=None, **kwargs):
 
     - Note 1: excess args and unmatched kwargs will be unused in the student environment.
     - Note 2: positional arguments are more robust to the student using different names for context values.
-    - Note 3: If an argument is specified both by name and position args, ``set_context()`` will use the named arg.
+    - Note 3: You have to specify arguments either by position, either by name. A combination is not possible.
 
     :Example:
 
@@ -371,28 +374,45 @@ def set_context(*args, state=None, **kwargs):
                 multi([s.has_equal_output(context_vals=[i]) for i in range(1, 4)])
 
     """
+
     stu_crnt = state.student_context.context
     sol_crnt = state.solution_context.context
+
+    # for now, you can't specify both
+    if len(args) > 0 and len(kwargs) > 0:
+        raise ValueError("In set_context() make sure to specify arguments either by position, either by name")
+
     # set args specified by pos -----------------------------------------------
-    # stop if too many pos args for solution
-    if len(args) > len(sol_crnt): 
-        raise IndexError("Too many positional args. There are {} context vals, but tried to set {}"
-                            .format(len(sol_crnt), len(args)))
-    # set pos args
-    upd_sol = sol_crnt.update(dict(zip(stu_crnt.keys(), args)))
-    upd_stu = stu_crnt.update(dict(zip(sol_crnt.keys(), args)))
+    if args:
+        # stop if too many pos args for solution
+        if len(args) > len(sol_crnt): 
+            raise IndexError("Too many positional args. There are {} context vals, but tried to set {}"
+                                .format(len(sol_crnt), len(args)))
+        # set pos args
+        upd_sol = sol_crnt.update(dict(zip(sol_crnt.keys(), args)))
+        upd_stu = stu_crnt.update(dict(zip(stu_crnt.keys(), args)))
+    else:
+        upd_sol = sol_crnt
+        upd_stu = stu_crnt
 
     # set args specified by keyword -------------------------------------------
-    if set(kwargs) - set(upd_sol):
-        raise KeyError("Context val names are {}, but tried to set {}"
-                            .format(upd_sol or "none", kwargs.keys()))
-    out_sol = upd_sol.update(kwargs)
-    # need to match keys in kwargs with corresponding keys in stu context
-    # in case they used, e.g., different loop variable names
-    match_keys = dict(zip(sol_crnt.keys(), stu_crnt.keys()))
-    out_stu = upd_stu.update({match_keys[k]: v for k,v in kwargs.items() if k in match_keys})
+    if kwargs:
+        # stop if keywords don't match with solution
+        if set(kwargs) - set(upd_sol):
+            raise KeyError("Context val names are {}, but tried to set {}"
+                                .format(upd_sol or "none", kwargs.keys()))
+        out_sol = upd_sol.update(kwargs)
+        # need to match keys in kwargs with corresponding keys in stu context
+        # in case they used, e.g., different loop variable names
+        match_keys = dict(zip(sol_crnt.keys(), stu_crnt.keys()))
+        out_stu = upd_stu.update({match_keys[k]: v for k,v in kwargs.items() if k in match_keys})
+    else:
+        out_sol = upd_sol
+        out_stu = upd_stu
 
-    return state.to_child_state(student_context = out_stu, solution_context = out_sol)
+    return state.to_child_state(student_context = out_stu,
+                                solution_context = out_sol,
+                                highlight = state.highlight)
 
 def set_env(state = None, **kwargs):
     """Update/set environemnt variables for student and solution environments.
@@ -430,12 +450,14 @@ def set_env(state = None, **kwargs):
     stu_new = stu_crnt.update(kwargs)
     sol_new = sol_crnt.update(kwargs)
 
-    return state.to_child_state(student_env = stu_new, solution_env = sol_new)
+    return state.to_child_state(student_env = stu_new,
+                                solution_env = sol_new,
+                                highlight = state.highlight)
 
 def disable_highlighting(state = None):
     """Disable highlighting in the remainder of the SCT chain.
 
-    Include this function if you want to avoid that ``pythonwhat`` marks which part of the student submission is incorrect.
+    Include this function if you want to avoid that pythonwhat marks which part of the student submission is incorrect.
 
     :Examples:
 
@@ -649,12 +671,12 @@ def call(args,
 
     if (test == 'error') ^ isinstance(eval_sol, Exception):
         _msg = state.build_message("FMT:Calling {argstr} resulted in an error (or not an error if testing for one). Error message: {type_err} {str_sol}",
-                                   dict(args=args, type_err=type(eval_sol), str_sol=str_sol))
+                                   dict(type_err=type(eval_sol), str_sol=str_sol, argstr=argstr)),
         raise ValueError(_msg)
 
     if isinstance(eval_sol, ReprFail):
         _msg = state.build_message("FMT:Can't get the result of calling {argstr}: {eval_sol.info}",
-                                   dict(args = args, eval_sol=eval_sol))
+                                   dict(argstr = argstr, eval_sol=eval_sol))
         raise ValueError(_msg)
 
     # Run for Submission ------------------------------------------------------
@@ -759,7 +781,7 @@ def has_equal_ast(incorrect_msg=None,
 
     return state
 
-DEFAULT_INCORRECT_MSG="__JINJA__:Expected {{'' if test == 'value' else 'the {{test}} '}}`{{sol_eval}}`, but got `{{stu_eval}}`."
+DEFAULT_INCORRECT_MSG="__JINJA__:Expected {{test_desc}}`{{sol_eval}}`, but got `{{stu_eval}}`."
 DEFAULT_ERROR_MSG="__JINJA__:Running {{'it' if parent['part'] else 'the higlighted expression'}} generated an error: `{{stu_str}}`."
 DEFAULT_ERROR_MSG_INV="__JINJA__:Running {{'it' if parent['part'] else 'the higlighted expression'}} didn't generate an error, but it should!"
 DEFAULT_UNDEFINED_NAME_MSG="__JINJA__:Running {{'it' if parent['part'] else 'the higlighted expression'}} should define a variable `{{name}}` without errors, but it doesn't."
@@ -815,9 +837,12 @@ def has_expr(incorrect_msg=None,
                                  env = state.student_env)
 
     # kwargs ---
-    fmt_kwargs = {'stu_part': state.student_parts, 'sol_part': state.solution_parts, 
-                  'name': name, 'test': test,
-                  'extra_env': str(extra_env) if extra_env else "", 'context_vals': context_vals}
+    fmt_kwargs = {
+        'stu_part': state.student_parts,
+        'sol_part': state.solution_parts,
+        'name': name, 'test': test,
+        'test_desc': '' if test == 'value' else 'the %s ' % test
+    }
     fmt_kwargs['stu_eval'] = utils.shorten_str(str(eval_stu))
     fmt_kwargs['sol_eval'] = utils.shorten_str(str(eval_sol))
 
